@@ -49,15 +49,18 @@ test_that("data is checked correctly", {
     plot_ftir(ftir = "abc"),
     "`ftir` must be a data frame. You provided a string."
   )
-  expect_error(plot_ftir(ftir = data.frame("a" = 1:10)),
+  expect_error(
+    plot_ftir(ftir = data.frame("a" = 1:10)),
     "It must contain a column named",
     fixed = TRUE
   )
-  expect_error(plot_ftir(ftir = full_data_df[, c("sample_id", "wavenumber")]),
+  expect_error(
+    plot_ftir(ftir = full_data_df[, c("sample_id", "wavenumber")]),
     "Error in `PlotFTIR::plot_ftir()`. `ftir` must have one of `absorbance` or `transmittance` columns.",
     fixed = TRUE
   )
-  expect_error(plot_ftir(ftir = full_data_df),
+  expect_error(
+    plot_ftir(ftir = full_data_df),
     "`ftir` cannot contain both `absorbance` and `transmittance` columns.",
     fixed = TRUE
   )
@@ -66,51 +69,62 @@ test_that("data is checked correctly", {
     plot_ftir_stacked(ftir = "abc"),
     "`ftir` must be a data frame. You provided a string."
   )
-  expect_error(plot_ftir_stacked(ftir = data.frame("a" = 1:10)),
+  expect_error(
+    plot_ftir_stacked(ftir = data.frame("a" = 1:10)),
     "`ftir` is missing a column",
     fixed = TRUE
   )
-  expect_error(plot_ftir_stacked(ftir = full_data_df[, c("sample_id", "wavenumber")]),
+  expect_error(
+    plot_ftir_stacked(ftir = full_data_df[, c("sample_id", "wavenumber")]),
     "`ftir` must have one of `absorbance` or `transmittance` columns.",
     fixed = TRUE
   )
-  expect_error(plot_ftir_stacked(ftir = full_data_df),
+  expect_error(
+    plot_ftir_stacked(ftir = full_data_df),
     "`ftir` cannot contain both `absorbance` and `transmittance` columns.",
     fixed = TRUE
   )
 
   colnames(full_data_df)[4] <- "logabs"
-  expect_error(plot_ftir(ftir = full_data_df),
+  expect_error(
+    plot_ftir(ftir = full_data_df),
     "`ftir` may only contain columns `sample_id`, `wavenumber`, and one of `absorbance` or `transmittance`.",
     fixed = TRUE
   )
-  expect_error(plot_ftir(biodiesel, 1234),
+  expect_error(
+    plot_ftir(biodiesel, 1234),
     "`plot_title` must be a character string or vector of strings with length not more than two.",
     fixed = TRUE
   )
-  expect_error(plot_ftir(biodiesel, c("My Plot", "My Subplot", "My Extrasubplot")),
+  expect_error(
+    plot_ftir(biodiesel, c("My Plot", "My Subplot", "My Extrasubplot")),
     "`plot_title` must be a character string or vector of strings with length not more than two.",
     fixed = TRUE
   )
-  expect_error(plot_ftir(biodiesel, legend_title = 1234),
+  expect_error(
+    plot_ftir(biodiesel, legend_title = 1234),
     "`legend_title` must be a single character string.",
     fixed = TRUE
   )
 
-  expect_error(plot_ftir_stacked(ftir = full_data_df),
+  expect_error(
+    plot_ftir_stacked(ftir = full_data_df),
     "`ftir` may only contain columns `sample_id`, `wavenumber`, and one of `absorbance` or `transmittance`.",
     fixed = TRUE
   )
-  expect_error(plot_ftir_stacked(biodiesel, stack_offset = "abc"),
+  expect_error(
+    plot_ftir_stacked(biodiesel, stack_offset = "abc"),
     "`stack_offset` must be a single numeric value.",
     fixed = TRUE
   )
-  expect_error(plot_ftir_stacked(biodiesel, stack_offset = -10),
+  expect_error(
+    plot_ftir_stacked(biodiesel, stack_offset = -10),
     "`stack_offset` must be between 0 and 200.",
     fixed = TRUE
   )
 
-  expect_warning(plot_ftir(rbind(biodiesel, sample_spectra)),
+  expect_warning(
+    plot_ftir(rbind(biodiesel, sample_spectra)),
     "The color palette in use works best with 12 or fewer unique samples in",
     fixed = TRUE
   )
@@ -121,11 +135,13 @@ test_that("Language settings work", {
     testthat::skip("ggplot2 not available for testing language integration")
   }
 
-  expect_error(plot_ftir(biodiesel, lang = "bob"),
+  expect_error(
+    plot_ftir(biodiesel, lang = "bob"),
     "`lang` must be one of ",
     fixed = TRUE
   )
-  expect_error(plot_ftir_stacked(biodiesel, lang = "bob"),
+  expect_error(
+    plot_ftir_stacked(biodiesel, lang = "bob"),
     "`lang` must be one of ",
     fixed = TRUE
   )
@@ -135,7 +151,11 @@ test_that("Language settings work", {
   expect_equal(p$labels$title, "Spectres IRTF")
   expect_equal(p$labels$x, bquote("Nombre d'onde" ~ (cm^-1)))
 
-  p2 <- plot_ftir(biodiesel, lang = "fr", plot_title = c("My Plot", "my subtitle"))
+  p2 <- plot_ftir(
+    biodiesel,
+    lang = "fr",
+    plot_title = c("My Plot", "my subtitle")
+  )
   expect_equal(p2$labels$title, "My Plot")
   expect_equal(p2$labels$x, bquote("Nombre d'onde" ~ (cm^-1)))
 })
